==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_functions/mp0025_001/MP0025_SyncWorkOrder_001.java <==

package net.datastream.schemas.mp_functions.mp0025_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.workorder_001.WorkOrder;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrder_001}WorkOrder"/>
 *       &lt;/sequence>
 *       &lt;attribute name="replace_mec_eq" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       &lt;attribute name="deleteActivities" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *       &lt;attribute name="autoproductionrequestprompt" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" />
 *       &lt;attribute name="completenonevaluatedsurveyequipprompt" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" />
 *       &lt;attribute name="confirmadddeletechecklist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       &lt;attribute name="confirmincompletechecklist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       &lt;attribute name="confirmworkorderhasfollowupchecklist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       &lt;attribute name="confirmrouteequipmentchecklist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       &lt;attribute name="confirmequipmentchecklist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       &lt;attribute name="iscontractorportal" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="WorkOrder" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workOrder"
})
@XmlRootElement(name = "MP0025_SyncWorkOrder_001")
public class MP0025_SyncWorkOrder_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "WorkOrder", namespace = "http://schemas.datastream.net/MP_entities/WorkOrder_001", required = true)
    protected WorkOrder workOrder;
    @XmlAttribute(name = "replace_mec_eq")
    protected Boolean replace_Mec_Eq;
    @XmlAttribute(name = "deleteActivities")
    protected String deleteActivities;
    @XmlAttribute(name = "autoproductionrequestprompt")
    protected String autoproductionrequestprompt;
    @XmlAttribute(name = "completenonevaluatedsurveyequipprompt")
    protected String completenonevaluatedsurveyequipprompt;
    @XmlAttribute(name = "confirmadddeletechecklist")
    protected String confirmadddeletechecklist;
    @XmlAttribute(name = "confirmincompletechecklist")
    protected String confirmincompletechecklist;
    @XmlAttribute(name = "confirmworkorderhasfollowupchecklist")
    protected String confirmworkorderhasfollowupchecklist;
    @XmlAttribute(name = "confirmrouteequipmentchecklist")
    protected String confirmrouteequipmentchecklist;
    @XmlAttribute(name = "confirmequipmentchecklist")
    protected String confirmequipmentchecklist;
    @XmlAttribute(name = "iscontractorportal")
    protected Boolean iscontractorportal;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Obtient la valeur de la propriété workOrder.
     * 
     * @return
     *     possible object is
     *     {@link WorkOrder }
     *     
     */
    public WorkOrder getWorkOrder() {
        return workOrder;
    }

    /**
     * Définit la valeur de la propriété workOrder.
     * 
     * @param value
     *     allowed object is
     *     {@link WorkOrder }
     *     
     */
    public void setWorkOrder(WorkOrder value) {
        this.workOrder = value;
    }

    /**
     * Obtient la valeur de la propriété replace_Mec_Eq.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isReplace_Mec_Eq() {
        if (replace_Mec_Eq == null) {
            return false;
        } else {
            return replace_Mec_Eq;
        }
    }

    /**
     * Définit la valeur de la propriété replace_Mec_Eq.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setReplace_Mec_Eq(Boolean value) {
        this.replace_Mec_Eq = value;
    }

    /**
     * Obtient la valeur de la propriété deleteActivities.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDeleteActivities() {
        return deleteActivities;
    }

    /**
     * Définit la valeur de la propriété deleteActivities.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDeleteActivities(String value) {
        this.deleteActivities = value;
    }

    /**
     * Obtient la valeur de la propriété autoproductionrequestprompt.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAutoproductionrequestprompt() {
        return autoproductionrequestprompt;
    }

    /**
     * Définit la valeur de la propriété autoproductionrequestprompt.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAutoproductionrequestprompt(String value) {
        this.autoproductionrequestprompt = value;
    }

    /**
     * Obtient la valeur de la propriété completenonevaluatedsurveyequipprompt.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCompletenonevaluatedsurveyequipprompt() {
        return completenonevaluatedsurveyequipprompt;
    }

    /**
     * Définit la valeur de la propriété completenonevaluatedsurveyequipprompt.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCompletenonevaluatedsurveyequipprompt(String value) {
        this.completenonevaluatedsurveyequipprompt = value;
    }

    /**
     * Obtient la valeur de la propriété confirmadddeletechecklist.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmadddeletechecklist() {
        if (confirmadddeletechecklist == null) {
            return "prompt";
        } else {
            return confirmadddeletechecklist;
        }
    }

    /**
     * Définit la valeur de la propriété confirmadddeletechecklist.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmadddeletechecklist(String value) {
        this.confirmadddeletechecklist = value;
    }

    /**
     * Obtient la valeur de la propriété confirmincompletechecklist.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmincompletechecklist() {
        if (confirmincompletechecklist == null) {
            return "prompt";
        } else {
            return confirmincompletechecklist;
        }
    }

    /**
     * Définit la valeur de la propriété confirmincompletechecklist.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmincompletechecklist(String value) {
        this.confirmincompletechecklist = value;
    }

    /**
     * Obtient la valeur de la propriété confirmworkorderhasfollowupchecklist.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmworkorderhasfollowupchecklist() {
        if (confirmworkorderhasfollowupchecklist == null) {
            return "prompt";
        } else {
            return confirmworkorderhasfollowupchecklist;
        }
    }

    /**
     * Définit la valeur de la propriété confirmworkorderhasfollowupchecklist.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmworkorderhasfollowupchecklist(String value) {
        this.confirmworkorderhasfollowupchecklist = value;
    }

    /**
     * Obtient la valeur de la propriété confirmrouteequipmentchecklist.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmrouteequipmentchecklist() {
        if (confirmrouteequipmentchecklist == null) {
            return "prompt";
        } else {
            return confirmrouteequipmentchecklist;
        }
    }

    /**
     * Définit la valeur de la propriété confirmrouteequipmentchecklist.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmrouteequipmentchecklist(String value) {
        this.confirmrouteequipmentchecklist = value;
    }

    /**
     * Obtient la valeur de la propriété confirmequipmentchecklist.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmequipmentchecklist() {
        if (confirmequipmentchecklist == null) {
            return "prompt";
        } else {
            return confirmequipmentchecklist;
        }
    }

    /**
     * Définit la valeur de la propriété confirmequipmentchecklist.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmequipmentchecklist(String value) {
        this.confirmequipmentchecklist = value;
    }

    /**
     * Obtient la valeur de la propriété iscontractorportal.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIscontractorportal() {
        if (iscontractorportal == null) {
            return false;
        } else {
            return iscontractorportal;
        }
    }

    /**
     * Définit la valeur de la propriété iscontractorportal.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIscontractorportal(Boolean value) {
        this.iscontractorportal = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.WORK_ORDER;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_functions/mp0025_001/MP0025_SyncWorkOrder_001.java <==

package net.datastream.schemas.mp_functions.mp0025_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.workorder_001.WorkOrder;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_entities/WorkOrder_001}WorkOrder"/>
 *       </sequence>
 *       <attribute name="replace_mec_eq" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="deleteActivities" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *       <attribute name="autoproductionrequestprompt" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" />
 *       <attribute name="completenonevaluatedsurveyequipprompt" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" />
 *       <attribute name="confirmadddeletechecklist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       <attribute name="confirmincompletechecklist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       <attribute name="confirmworkorderhasfollowupchecklist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       <attribute name="confirmrouteequipmentchecklist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       <attribute name="confirmequipmentchecklist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       <attribute name="iscontractorportal" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       <attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="WorkOrder" />
 *       <attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workOrder"
})
@XmlRootElement(name = "MP0025_SyncWorkOrder_001")
public class MP0025_SyncWorkOrder_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "WorkOrder", namespace = "http://schemas.datastream.net/MP_entities/WorkOrder_001", required = true)
    protected WorkOrder workOrder;
    @XmlAttribute(name = "replace_mec_eq")
    protected Boolean replace_Mec_Eq;
    @XmlAttribute(name = "deleteActivities")
    protected String deleteActivities;
    @XmlAttribute(name = "autoproductionrequestprompt")
    protected String autoproductionrequestprompt;
    @XmlAttribute(name = "completenonevaluatedsurveyequipprompt")
    protected String completenonevaluatedsurveyequipprompt;
    @XmlAttribute(name = "confirmadddeletechecklist")
    protected String confirmadddeletechecklist;
    @XmlAttribute(name = "confirmincompletechecklist")
    protected String confirmincompletechecklist;
    @XmlAttribute(name = "confirmworkorderhasfollowupchecklist")
    protected String confirmworkorderhasfollowupchecklist;
    @XmlAttribute(name = "confirmrouteequipmentchecklist")
    protected String confirmrouteequipmentchecklist;
    @XmlAttribute(name = "confirmequipmentchecklist")
    protected String confirmequipmentchecklist;
    @XmlAttribute(name = "iscontractorportal")
    protected Boolean iscontractorportal;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Gets the value of the workOrder property.
     * 
     * @return
     *     possible object is
     *     {@link WorkOrder }
     *     
     */
    public WorkOrder getWorkOrder() {
        return workOrder;
    }

    /**
     * Sets the value of the workOrder property.
     * 
     * @param value
     *     allowed object is
     *     {@link WorkOrder }
     *     
     */
    public void setWorkOrder(WorkOrder value) {
        this.workOrder = value;
    }

    /**
     * Gets the value of the replace_Mec_Eq property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isReplace_Mec_Eq() {
        if (replace_Mec_Eq == null) {
            return false;
        } else {
            return replace_Mec_Eq;
        }
    }

    /**
     * Sets the value of the replace_Mec_Eq property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setReplace_Mec_Eq(Boolean value) {
        this.replace_Mec_Eq = value;
    }

    /**
     * Gets the value of the deleteActivities property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDeleteActivities() {
        return deleteActivities;
    }

    /**
     * Sets the value of the deleteActivities property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDeleteActivities(String value) {
        this.deleteActivities = value;
    }

    /**
     * Gets the value of the autoproductionrequestprompt property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAutoproductionrequestprompt() {
        return autoproductionrequestprompt;
    }

    /**
     * Sets the value of the autoproductionrequestprompt property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAutoproductionrequestprompt(String value) {
        this.autoproductionrequestprompt = value;
    }

    /**
     * Gets the value of the completenonevaluatedsurveyequipprompt property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCompletenonevaluatedsurveyequipprompt() {
        return completenonevaluatedsurveyequipprompt;
    }

    /**
     * Sets the value of the completenonevaluatedsurveyequipprompt property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCompletenonevaluatedsurveyequipprompt(String value) {
        this.completenonevaluatedsurveyequipprompt = value;
    }

    /**
     * Gets the value of the confirmadddeletechecklist property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmadddeletechecklist() {
        if (confirmadddeletechecklist == null) {
            return "prompt";
        } else {
            return confirmadddeletechecklist;
        }
    }

    /**
     * Sets the value of the confirmadddeletechecklist property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmadddeletechecklist(String value) {
        this.confirmadddeletechecklist = value;
    }

    /**
     * Gets the value of the confirmincompletechecklist property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmincompletechecklist() {
        if (confirmincompletechecklist == null) {
            return "prompt";
        } else {
            return confirmincompletechecklist;
        }
    }

    /**
     * Sets the value of the confirmincompletechecklist property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmincompletechecklist(String value) {
        this.confirmincompletechecklist = value;
    }

    /**
     * Gets the value of the confirmworkorderhasfollowupchecklist property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmworkorderhasfollowupchecklist() {
        if (confirmworkorderhasfollowupchecklist == null) {
            return "prompt";
        } else {
            return confirmworkorderhasfollowupchecklist;
        }
    }

    /**
     * Sets the value of the confirmworkorderhasfollowupchecklist property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmworkorderhasfollowupchecklist(String value) {
        this.confirmworkorderhasfollowupchecklist = value;
    }

    /**
     * Gets the value of the confirmrouteequipmentchecklist property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmrouteequipmentchecklist() {
        if (confirmrouteequipmentchecklist == null) {
            return "prompt";
        } else {
            return confirmrouteequipmentchecklist;
        }
    }

    /**
     * Sets the value of the confirmrouteequipmentchecklist property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmrouteequipmentchecklist(String value) {
        this.confirmrouteequipmentchecklist = value;
    }

    /**
     * Gets the value of the confirmequipmentchecklist property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmequipmentchecklist() {
        if (confirmequipmentchecklist == null) {
            return "prompt";
        } else {
            return confirmequipmentchecklist;
        }
    }

    /**
     * Sets the value of the confirmequipmentchecklist property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmequipmentchecklist(String value) {
        this.confirmequipmentchecklist = value;
    }

    /**
     * Gets the value of the iscontractorportal property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIscontractorportal() {
        if (iscontractorportal == null) {
            return false;
        } else {
            return iscontractorportal;
        }
    }

    /**
     * Sets the value of the iscontractorportal property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIscontractorportal(Boolean value) {
        this.iscontractorportal = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.WORK_ORDER;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}
